<?php

/**
 * @file
 * Contains Drupal\disable_back_button_config\Form\DisableBackConfigForm.
 */

namespace Drupal\disable_back_button\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Database;

/**
 * Displays the disable browser back button settings form.
 */
class DisableBackConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'disable_back_button_config.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'disable_back_button_config_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function pageTitle() {
    return 'Disable Browser Back configuration';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('disable_back_button_config.settings');
    // List of url's where we have to disable browser back functionality.
    $form['url_list'] = array(
      '#type' => 'textarea',
      '#title' => $this->t('Enter comma seprated page url where you want to disable browser back functionality'),
      '#default_value' => $config->get('no_back'),
    );
   // Submit button
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $no_back_string = trim($form_state->getValue('url_list'));
    $trimed_String = str_replace(" ","",$no_back_string);
    $this->configFactory->getEditable('disable_back_button_config.settings')
        // Set the submitted configuration setting
        ->set('no_back', $trimed_String)
        ->save();
  }

}
